@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2021, J. D. Mitchell
+# Copyright (c) 2021-2022, J. D. Mitchell
 #
 # Distributed under the terms of the GPL license version 3.
 #
@@ -9,11 +9,12 @@
 # pylint: disable=no-name-in-module
 
 """
-This package provides a the user-facing python part of libsemigroups_pybind11
+This package provides the user-facing python part of libsemigroups_pybind11
 """
 
 from _libsemigroups_pybind11 import (
     PBR,
+    NEGATIVE_INFINITY,
     POSITIVE_INFINITY,
     UNDEFINED,
     ActionDigraph,
@@ -34,6 +35,7 @@ from _libsemigroups_pybind11 import (
     tril,
     wilo,
     wislo,
+    Sims1,
 )
 
 from .froidure_pin import FroidurePin
